<!--
name: 'System Reminder: TodoWrite reminder'
description: Reminder to use TodoWrite tool for task tracking
ccVersion: 2.1.18
-->
The TodoWrite tool hasn't been used recently. If you're working on tasks that would benefit from tracking progress, consider using the TodoWrite tool to track progress. Also consider cleaning up the todo list if has become stale and no longer matches what you are working on. Only use it if it's relevant to the current work. This is just a gentle reminder - ignore if not applicable. Make sure that you NEVER mention this reminder to the user
